@@ -132,8 +132,8 @@ def component_verify_ticket_push_func(component_appid, component_secret, compone
 
 
 def we_oauth2(request):
-    scope = request.GET.get('scope', 'snsapi_userinfo') or request.GET.get('s', '')
-    redirect_url = request.GET.get('redirect_url', '') or request.GET.get('r', '')
+    scope = request.GET.get('scope', '') or request.GET.get('s', 'snsapi_userinfo')
+    redirect_url = request.GET.get('redirect_url', '') or request.GET.get('r', '/')
     default_url = request.GET.get('default_url', '') or request.GET.get('d', '')
     direct_redirect = bool(request.GET.get('direct_redirect', '') or request.GET.get('dr', ''))
 
@@ -189,7 +189,7 @@ def base_redirect(request):
         return render(request, 'django_we/errmsg.html', {'title': 'Error', 'errmsg': 'DJANGO_WE_BASE_COOKIE_FUNC Should Exists'})
 
     if hasattr(settings, 'DJANGO_WE_BASE_FUNC') and hasattr(settings.DJANGO_WE_BASE_FUNC, '__call__'):
-        query_params = settings.DJANGO_WE_BASE_FUNC(code, final_state, access_info)
+        query_params = settings.DJANGO_WE_BASE_FUNC(code, final_state, access_info) or {}
 
     return redirect(furl(final_state).remove(access_info.keys()).add(access_info).remove(query_params.keys()).add(query_params).url)
 
@@ -292,6 +292,8 @@ def we_share(request):
 
 @auto_response
 def we_jsapi_signature_api(request, state=None):
+    if hasattr(settings, 'DJANGO_WE_ENABLED_OR_NOT') and not getattr(settings, 'DJANGO_WE_ENABLED_OR_NOT'):
+        return {}
     CFG = final_cfg(request, state=state or 'jsapi_signature')
     return jsapi_signature_params(
         CFG['appID'],
@@ -315,6 +317,7 @@ def we_access_token(request, state=None):
     CFG = final_cfg(request, state=state or 'access_token')
 
     return {
+        'appid': CFG['appID'],
         'access_token': fetch_func(
             CFG['appID'],
             CFG['appsecret'],
